@@ -95,7 +95,15 @@ def radcal(ras, save=False, quiet=True, debug=False):
     elif hdulistin:
         rasfits=ras[0]
 
-    end=dt.datetime.strptime(rasfits[0].header['ENDOBS'], '%Y-%m-%dT%H:%M:%S.%f')
+    if 'STARTOBS' not in rasfits[0].header:
+        begin=dt.datetime.strptime(rasfits[0].header['DATE_OBS'], '%Y-%m-%dT%H:%M:%S.%f')
+    else:
+        begin=dt.datetime.strptime(rasfits[0].header['STARTOBS'], '%Y-%m-%dT%H:%M:%S.%f')
+    if 'ENDOBS' not in rasfits[0].header:
+        end=dt.datetime.strptime(rasfits[0].header['DATE_END'], '%Y-%m-%dT%H:%M:%S.%f')
+    else:
+        end=dt.datetime.strptime(rasfits[0].header['ENDOBS'], '%Y-%m-%dT%H:%M:%S.%f')
+
     midtime=dt.datetime.strftime((begin+((end-begin)/2)), '%Y-%m-%dT%H:%M:%S.%fZ')
 
     response=(igr.iris_get_response(midtime))[0]
@@ -196,7 +204,10 @@ def radcal(ras, save=False, quiet=True, debug=False):
     #Spectral Pixel Width [angstroms]#
     ##################################
 
-    pixl={key: rasfits[indices[key]].header['CDELT1'] for key in indices}
+    if 'NUV' in indices or 'FUV' in indices:
+        pixl={key: rasfits[indices[key]].header['CDELT3'] for key in indices}
+    else:
+        pixl={key: rasfits[indices[key]].header['CDELT1'] for key in indices}
 
     ##############################
     #Spatial Pixel Size [radians]#
@@ -239,7 +250,7 @@ def radcal(ras, save=False, quiet=True, debug=False):
     rcfs={} #Radiometric Calibration FactorS
     for key in indices:
         if key=='FUV':
-            wvlns[key]=np.add(np.multiply(np.subtract(np.arange(0, rasfits[indices[key]].header['NAXIS1']), rasfits[indices[key]].header['CRPIX1']-1), rasfits[indices[key]].header['CDELT1']), rasfits[indices[key]].header['CRVAL1'])
+            wvlns[key]=np.add(np.multiply(np.subtract(np.arange(0, rasfits[indices[key]].header['NAXIS3']), rasfits[indices[key]].header['CRPIX3']-1), rasfits[indices[key]].header['CDELT3']), rasfits[indices[key]].header['CRVAL3'])
             lamwin[key]=[-1, -1]
             for ind, wvln in enumerate(wvlns[key]):
                 if wvln>=FUV1[0] and lamwin[key][0]==-1:
@@ -249,7 +260,7 @@ def radcal(ras, save=False, quiet=True, debug=False):
                     break
             rcfs[key]=f_FUV1(wvlns[key][lamwin[key][0]:lamwin[key][1]])*const[key]
         elif key=='NUV':
-            wvlns[key]=np.add(np.multiply(np.subtract(np.arange(0, rasfits[indices[key]].header['NAXIS1']), rasfits[indices[key]].header['CRPIX1']-1), rasfits[indices[key]].header['CDELT1']), rasfits[indices[key]].header['CRVAL1'])
+            wvlns[key]=np.add(np.multiply(np.subtract(np.arange(0, rasfits[indices[key]].header['NAXIS3']), rasfits[indices[key]].header['CRPIX3']-1), rasfits[indices[key]].header['CDELT3']), rasfits[indices[key]].header['CRVAL3'])
             lamwin[key]=[-1, -1]
             for ind, wvln in enumerate(wvlns[key]):
                 if wvln>=NUV[0] and lamwin[key][0]==-1:
@@ -322,13 +333,13 @@ def radcal(ras, save=False, quiet=True, debug=False):
 
         for key in indices: 
             dat[key]=dc(rasfits[indices[key]].data[...,lamwin[key][0]:lamwin[key][1]])
-            for ind, _ in np.ndenumerate(dat[key][...,0]):
-                dat[key][ind]=np.multiply(dat[key][ind], rcfs[key])
-            hdrdict[key]=dc(rasfits[indices[key]].header)
-            hdrdict[key]['CRVAL1']=wvlns[key][lamwin[key][0]]
-            hdrdict[key]['NAXIS1']=lamwin[key][1]-lamwin[key][0]+1 #Counting "0", of course
 
-            if key!='NUV' and key!='FUV': #Full disc
+            if key!='NUV' and key!='FUV': #Not full disc
+                for ind, _ in np.ndenumerate(dat[key][...,0]):
+                    dat[key][ind]=np.multiply(dat[key][ind], rcfs[key])
+                hdrdict[key]=dc(rasfits[indices[key]].header)
+                hdrdict[key]['CRVAL1']=wvlns[key][lamwin[key][0]]
+                hdrdict[key]['NAXIS1']=lamwin[key][1]-lamwin[key][0]+1 #Counting "0", of course
 
                 hdr0['TWMIN'+str(indices[key])]=wvlns[key][lamwin[key][0]]
                 hdr0['TWMAX'+str(indices[key])]=wvlns[key][lamwin[key][1]]
@@ -350,6 +361,12 @@ def radcal(ras, save=False, quiet=True, debug=False):
                 hdr0['TDP98_'+str(indices[key])]=flatdat[int(np.round(len(flatdat)*0.98))]
                 hdr0['TDP99_'+str(indices[key])]=flatdat[int(np.round(len(flatdat)*0.99))]
                 del flatdat
+            else:
+                for ind, _ in np.ndenumerate(dat[key][0]):
+                    dat[key][ind]=np.multiply(dat[key][ind], rcfs[key])
+                hdrdict[key]=dc(rasfits[indices[key]].header)
+                hdrdict[key]['CRVAL3']=wvlns[key][lamwin[key][0]]
+                hdrdict[key]['NAXIS3']=lamwin[key][1]-lamwin[key][0]+1 #Counting "0", of course
 
         if key!='NUV' and key!='FUV': #Full disc
             for ind, key in enumerate(dat):
